codegen Package
===============

:mod:`codegen` Package
----------------------

.. automodule:: numba.codegen
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`codeutils` Module
-----------------------

.. automodule:: numba.codegen.codeutils
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`coerce` Module
--------------------

.. automodule:: numba.codegen.coerce
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`complexsupport` Module
----------------------------

.. automodule:: numba.codegen.complexsupport
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`debug` Module
-------------------

.. automodule:: numba.codegen.debug
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`globalconstants` Module
-----------------------------

.. automodule:: numba.codegen.globalconstants
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`llvmcontext` Module
-------------------------

.. automodule:: numba.codegen.llvmcontext
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`llvmwrapper` Module
-------------------------

.. automodule:: numba.codegen.llvmwrapper
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`refcounting` Module
-------------------------

.. automodule:: numba.codegen.refcounting
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`translate` Module
-----------------------

.. automodule:: numba.codegen.translate
    :members:
    :undoc-members:
    :show-inheritance:

